# Retrieving a Diagram by ID
### On this page
  * [Retrieving All Diagrams](https://help.sap.com/docs/leanix/ea/retrieving-diagram-by-id#retrieving-all-diagrams)
  * [Retrieving a Diagram by ID](https://help.sap.com/docs/leanix/ea/retrieving-diagram-by-id#retrieving-a-diagram-by-id)


This guide explains how to retrieve all or specific diagrams that you have access to through the Pathfinder REST API.
To learn how to authenticate to SAP LeanIX APIs, see [Authentication to SAP LeanIX Services](https://help.sap.com/docs/leanix/ea/authentication-to-sap-leanix-services?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to authenticate to SAP LeanIX services.").
